import { ReaderResult } from "flamingo/src/types/ReaderResult";
import { S3 } from "aws-sdk";
/**
 * S3 reader module
 * @module flamingo-s3/src/reader
 */
/**
 * Result of input reading
 * @typedef {{stream: function, type: string}} ReadResult
 * @property {string} type reader result type
 * @property {function} stream function that returns a readable image stream
 */
/**
 * Reader that creates a stream for a given http/https resource
 * @param {string} bucket bucket name
 * @param {string} key bucket key
 * @param {AWS} s3Client AWS s3 client
 * @return {Promise.<ReadResult>} promise that resolves a reader result
 */
declare function s3Reader(bucket: string, key: string, s3Client: S3): Promise<ReaderResult>;
export = s3Reader;
